//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Models/MultiLayerItem.h
//! @brief     Defines class MultiLayerItem
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODELS_MULTILAYERITEM_H
#define BORNAGAIN_GUI_MODELS_MULTILAYERITEM_H

#include "Base/Vector/Vectors3D.h"
#include "GUI/Models/SessionGraphicsItem.h"

class LayerItem;

class BA_CORE_API_ MultiLayerItem : public SessionGraphicsItem {
private:
    static const QString P_CROSS_CORR_LENGTH;
    static const QString P_EXTERNAL_FIELD;
    static const QString T_LAYERS;

public:
    static const QString M_TYPE;

    MultiLayerItem();

    QVector<SessionItem*> materialPropertyItems();

    double crossCorrLength() const;
    void setCrossCorrLength(double cross_corr_length);
    static bool isCrossCorrLengthPropertyName(const QString& name);

    kvector_t externalField() const;
    void setExternalField(const kvector_t& ext_field);
    SessionItem* externalFieldItem() const;

    QVector<LayerItem*> layers() const;
    SessionItem* layersItem() const;

private:
    void updateLayers();
};

#endif // BORNAGAIN_GUI_MODELS_MULTILAYERITEM_H
