//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Resample/FFCompute/ComputeBA.cpp
//! @brief     Implements class ComputeBA.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "Resample/FFCompute/ComputeBA.h"
#include "Base/Vector/WavevectorInfo.h"
#include "Sample/Scattering/IFormFactor.h"

ComputeBA::ComputeBA(const IFormFactor& ff, size_t i_layer) : IComputeScalar(ff, i_layer) {}

ComputeBA::~ComputeBA() = default;

ComputeBA* ComputeBA::clone() const
{
    return new ComputeBA(*m_ff, m_i_layer);
}

complex_t ComputeBA::computeFF(const WavevectorInfo& wavevectors,
                               const std::unique_ptr<const IFlux>&,
                               const std::unique_ptr<const IFlux>&) const
{
    return m_ff->theFF(wavevectors);
}
