//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Resample/FFCompute/ComputeBAPol.cpp
//! @brief     Defines class ComputeBAPol.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "Resample/FFCompute/ComputeBAPol.h"
#include "Base/Vector/WavevectorInfo.h"
#include "Sample/Scattering/IFormFactor.h"

ComputeBAPol::ComputeBAPol(const IFormFactor& ff, size_t i_layer) : IComputePol(ff, i_layer) {}

ComputeBAPol::~ComputeBAPol() = default;

ComputeBAPol* ComputeBAPol::clone() const
{
    return new ComputeBAPol(*m_ff, m_i_layer);
}

Eigen::Matrix2cd ComputeBAPol::computePolFF(const WavevectorInfo& wavevectors,
                                            const std::unique_ptr<const IFlux>&,
                                            const std::unique_ptr<const IFlux>&) const
{
    Eigen::Matrix2cd ff_BA = m_ff->thePolFF(wavevectors);
    Eigen::Matrix2cd result;
    result(0, 0) = -ff_BA(1, 0);
    result(0, 1) = ff_BA(0, 0);
    result(1, 0) = -ff_BA(1, 1);
    result(1, 1) = ff_BA(0, 1);
    return result;
}
