//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Resample/FFCompute/ComputeDWBA.h
//! @brief     Defines class ComputeDWBA.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif

#ifndef USER_API
#ifndef BORNAGAIN_RESAMPLE_FFCOMPUTE_COMPUTEDWBA_H
#define BORNAGAIN_RESAMPLE_FFCOMPUTE_COMPUTEDWBA_H

#include "Resample/FFCompute/IComputeScalar.h"
#include <memory>

class IFlux;

//! Provides scalar DWBA computation for given IFormFactor.

class ComputeDWBA : public IComputeScalar {
public:
    ComputeDWBA(const IFormFactor& ff, size_t i_layer);
    ~ComputeDWBA() override;

    ComputeDWBA* clone() const override;

    //! Returns the coherent sum of the four DWBA terms for scalar scattering.
    complex_t computeFF(const WavevectorInfo& wavevectors,
                        const std::unique_ptr<const IFlux>& inFlux,
                        const std::unique_ptr<const IFlux>& outFlux) const override;

    friend class TestPolarizedDWBATerm;
};

#endif // BORNAGAIN_RESAMPLE_FFCOMPUTE_COMPUTEDWBA_H
#endif // USER_API
