//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Resample/FFCompute/ComputeDWBAPol.h
//! @brief     Defines class ComputeDWBAPol.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif

#ifndef USER_API
#ifndef BORNAGAIN_RESAMPLE_FFCOMPUTE_COMPUTEDWBAPOL_H
#define BORNAGAIN_RESAMPLE_FFCOMPUTE_COMPUTEDWBAPOL_H

#include "Resample/FFCompute/IComputePol.h"
#include <memory>

class IFlux;

//! Provides polarized DWBA computation for given IFormFactor.

class ComputeDWBAPol : public IComputePol {
public:
    ComputeDWBAPol(const IFormFactor& ff, size_t i_layer);
    ~ComputeDWBAPol() override;

    ComputeDWBAPol* clone() const override;

    //! Returns the coherent sum of the four DWBA terms for polarized scattering.
    Eigen::Matrix2cd computePolFF(const WavevectorInfo& wavevectors,
                                  const std::unique_ptr<const IFlux>& inFlux,
                                  const std::unique_ptr<const IFlux>& outFlux) const override;

    friend class TestPolarizedDWBATerm;
};

#endif // BORNAGAIN_RESAMPLE_FFCOMPUTE_COMPUTEDWBAPOL_H
#endif // USER_API
