//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Resample/FFCompute/IComputePol.h
//! @brief     Defines class ComputeBA.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif

#ifndef USER_API
#ifndef BORNAGAIN_RESAMPLE_FFCOMPUTE_ICOMPUTEPOL_H
#define BORNAGAIN_RESAMPLE_FFCOMPUTE_ICOMPUTEPOL_H

#include "Resample/FFCompute/IComputeFF.h"
#include <Eigen/Core>

class DiffuseElement;
class WavevectorInfo;

//! Provides polarized form factor evaluation for given IFormFactor.
//! Inherited by ComputeBAPol and ComputeDWBAPol.

class IComputePol : public IComputeFF {
public:
    Eigen::Matrix2cd coherentPolFF(const DiffuseElement& sim_element) const;
    //! Returns scattering amplitude for matrix interactions
    virtual Eigen::Matrix2cd computePolFF(const WavevectorInfo& wavevectors,
                                          const std::unique_ptr<const IFlux>& inFlux,
                                          const std::unique_ptr<const IFlux>& outFlux) const = 0;

protected:
    IComputePol(const IFormFactor& ff, size_t i_layer) : IComputeFF(ff, i_layer) {}
};

#endif // BORNAGAIN_RESAMPLE_FFCOMPUTE_ICOMPUTEPOL_H
#endif // USER_API
