//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Resample/Specular/SpecularScalarStrategy.h
//! @brief     Defines class SpecularScalarStrategy.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif

#ifndef USER_API
#ifndef BORNAGAIN_RESAMPLE_SPECULAR_SPECULARSCALARSTRATEGY_H
#define BORNAGAIN_RESAMPLE_SPECULAR_SPECULARSCALARSTRATEGY_H

#include "Resample/Flux/ScalarFlux.h"
#include "Resample/Specular/ISpecularStrategy.h"
#include <memory>
#include <vector>

class SliceStack;

//! Implements the scalar Fresnel computation
//!
//! Implements method 'execute' to compute refraction angles and transmission/reflection
//! coefficients for coherent wave propagation in a multilayer.
//!
//! Inherited by SpecularScalarNCStrategy, SpecularScalarTanhStrategy
class SpecularScalarStrategy : public ISpecularStrategy {
public: // directly accessed in test
    //! Computes refraction angles and transmission/reflection coefficients
    //! for given coherent wave propagation in a multilayer.
    virtual Fluxes Execute(const SliceStack& slices,
                                                const kvector_t& k) const override;

protected:
    virtual std::pair<complex_t, complex_t> transition(complex_t kzi, complex_t kzi1,
                                                       double sigma) const = 0;

private:
    virtual Fluxes Execute(const SliceStack& slices,
                                                const std::vector<complex_t>& kz) const override;

    //! Computes the Fresnel R coefficient for the top layer only
    //! Introduced in order to speed up pure reflectivity computations
    virtual std::variant<complex_t, Eigen::Matrix2cd>
    computeTopLayerR(const SliceStack& slices, const std::vector<complex_t>& kz) const override;

    std::vector<Eigen::Vector2cd> computeTR(const SliceStack& slices,
                                            const std::vector<complex_t>& kz) const;
};

#endif // BORNAGAIN_RESAMPLE_SPECULAR_SPECULARSCALARSTRATEGY_H
#endif // USER_API
