//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Resample/Specular/SpecularStrategyBuilder.cpp
//! @brief     Implements class SpecularStrategyBuilder.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "Resample/Specular/SpecularStrategyBuilder.h"
#include "Base/Utils/Assert.h"
#include "Resample/Specular/SpecularMagneticNCStrategy.h"
#include "Resample/Specular/SpecularMagneticTanhStrategy.h"
#include "Resample/Specular/SpecularScalarNCStrategy.h"
#include "Resample/Specular/SpecularScalarTanhStrategy.h"

std::unique_ptr<SpecularScalarStrategy>
SampleUtils::SpecularStrategyBuilder::buildScalar(const RoughnessModel& rm)
{
    if (rm == RoughnessModel::TANH || rm == RoughnessModel::DEFAULT)
        return std::make_unique<SpecularScalarTanhStrategy>();

    if (rm == RoughnessModel::NEVOT_CROCE)
        return std::make_unique<SpecularScalarNCStrategy>();

    ASSERT(0);
}

std::unique_ptr<SpecularMagneticStrategy>
SampleUtils::SpecularStrategyBuilder::buildMagnetic(const RoughnessModel& rm)
{
    if (rm == RoughnessModel::TANH || rm == RoughnessModel::DEFAULT)
        return std::make_unique<SpecularMagneticTanhStrategy>();

    if (rm == RoughnessModel::NEVOT_CROCE)
        return std::make_unique<SpecularMagneticNCStrategy>();

    ASSERT(0);
}
