
// File: index.xml

// File: classCoherentFFSum.xml
%feature("docstring") CoherentFFSum "

Information about particle form factor and abundance.

C++ includes: FFSum.h
";

%feature("docstring")  CoherentFFSum::CoherentFFSum "CoherentFFSum::CoherentFFSum(double abundance, const std::vector< std::shared_ptr< const IComputeFF >> &terms)
";

%feature("docstring")  CoherentFFSum::summedFF "complex_t CoherentFFSum::summedFF(const DiffuseElement &sim_element) const
";

%feature("docstring")  CoherentFFSum::summedPolFF "Eigen::Matrix2cd CoherentFFSum::summedPolFF(const DiffuseElement &sim_element) const
";

%feature("docstring")  CoherentFFSum::relativeAbundance "double CoherentFFSum::relativeAbundance() const
";

%feature("docstring")  CoherentFFSum::radialExtension "double CoherentFFSum::radialExtension() const
";


// File: classComputeBA.xml
%feature("docstring") ComputeBA "

Provides scalar form factor evaluation in Born Approximation for given IFormFactor.

C++ includes: ComputeBA.h
";

%feature("docstring")  ComputeBA::ComputeBA "ComputeBA::ComputeBA(const IFormFactor &ff, size_t i_layer)
";

%feature("docstring")  ComputeBA::~ComputeBA "ComputeBA::~ComputeBA() override
";

%feature("docstring")  ComputeBA::clone "ComputeBA * ComputeBA::clone() const override
";

%feature("docstring")  ComputeBA::computeFF "complex_t ComputeBA::computeFF(const WavevectorInfo &wavevectors, const std::unique_ptr< const IFlux > &inFlux, const std::unique_ptr< const IFlux > &outFlux) const override

Calculates and returns a form factor calculation in BA. 
";


// File: classComputeBAPol.xml
%feature("docstring") ComputeBAPol "

Provides polarized form factor evaluation in Born Approximation for given IFormFactor.

C++ includes: ComputeBAPol.h
";

%feature("docstring")  ComputeBAPol::ComputeBAPol "ComputeBAPol::ComputeBAPol(const IFormFactor &ff, size_t i_layer)
";

%feature("docstring")  ComputeBAPol::~ComputeBAPol "ComputeBAPol::~ComputeBAPol() override
";

%feature("docstring")  ComputeBAPol::clone "ComputeBAPol * ComputeBAPol::clone() const override
";

%feature("docstring")  ComputeBAPol::computePolFF "Eigen::Matrix2cd ComputeBAPol::computePolFF(const WavevectorInfo &wavevectors, const std::unique_ptr< const IFlux > &, const std::unique_ptr< const IFlux > &) const override

Calculates and returns a polarized form factor calculation in BA. 
";


// File: classComputeDWBA.xml
%feature("docstring") ComputeDWBA "

Provides scalar DWBA computation for given IFormFactor.

C++ includes: ComputeDWBA.h
";

%feature("docstring")  ComputeDWBA::ComputeDWBA "ComputeDWBA::ComputeDWBA(const IFormFactor &ff, size_t i_layer)
";

%feature("docstring")  ComputeDWBA::~ComputeDWBA "ComputeDWBA::~ComputeDWBA() override
";

%feature("docstring")  ComputeDWBA::clone "ComputeDWBA * ComputeDWBA::clone() const override
";

%feature("docstring")  ComputeDWBA::computeFF "complex_t ComputeDWBA::computeFF(const WavevectorInfo &wavevectors, const std::unique_ptr< const IFlux > &inFlux, const std::unique_ptr< const IFlux > &outFlux) const override

Returns the coherent sum of the four DWBA terms for scalar scattering. 
";


// File: classComputeDWBAPol.xml
%feature("docstring") ComputeDWBAPol "

Provides polarized DWBA computation for given IFormFactor.

C++ includes: ComputeDWBAPol.h
";

%feature("docstring")  ComputeDWBAPol::ComputeDWBAPol "ComputeDWBAPol::ComputeDWBAPol(const IFormFactor &ff, size_t i_layer)
";

%feature("docstring")  ComputeDWBAPol::~ComputeDWBAPol "ComputeDWBAPol::~ComputeDWBAPol() override
";

%feature("docstring")  ComputeDWBAPol::clone "ComputeDWBAPol * ComputeDWBAPol::clone() const override
";

%feature("docstring")  ComputeDWBAPol::computePolFF "Eigen::Matrix2cd ComputeDWBAPol::computePolFF(const WavevectorInfo &wavevectors, const std::unique_ptr< const IFlux > &inFlux, const std::unique_ptr< const IFlux > &outFlux) const override

Returns the coherent sum of the four DWBA terms for polarized scattering. 
";


// File: classDecouplingApproximationStrategy.xml
%feature("docstring") DecouplingApproximationStrategy "

Strategy class to compute the total scattering from a particle layout in the decoupling approximation.

C++ includes: DecouplingApproximationStrategy.h
";

%feature("docstring")  DecouplingApproximationStrategy::DecouplingApproximationStrategy "DecouplingApproximationStrategy::DecouplingApproximationStrategy(const std::vector< CoherentFFSum > &weighted_formfactors, const IInterferenceFunction *iff, SimulationOptions sim_params, bool polarized)
";


// File: classDiffuseElement.xml
%feature("docstring") DiffuseElement "

Data stucture containing both input and output of a single detector cell.

C++ includes: DiffuseElement.h
";

%feature("docstring")  DiffuseElement::DiffuseElement "DiffuseElement::DiffuseElement(double wavelength, double alpha_i, double phi_i, std::unique_ptr< IPixel > pixel, const Eigen::Matrix2cd &beam_polarization, const Eigen::Matrix2cd &analyzer, bool isSpecular_, const Fluxes *const fluxes_in=nullptr, const Fluxes *const fluxes_out=nullptr)
";

%feature("docstring")  DiffuseElement::DiffuseElement "DiffuseElement::DiffuseElement(const DiffuseElement &other)
";

%feature("docstring")  DiffuseElement::~DiffuseElement "DiffuseElement::~DiffuseElement()
";

%feature("docstring")  DiffuseElement::setFluxes "void DiffuseElement::setFluxes(const Fluxes *fluxes_in, const Fluxes *fluxes_out)
";

%feature("docstring")  DiffuseElement::fluxesIn "const Fluxes& DiffuseElement::fluxesIn() const
";

%feature("docstring")  DiffuseElement::fluxesOut "const Fluxes& DiffuseElement::fluxesOut() const
";

%feature("docstring")  DiffuseElement::pointElement "DiffuseElement DiffuseElement::pointElement(double x, double y) const

Returns copy of this  DiffuseElement with k_f given by in-pixel coordinate x,y. 
";

%feature("docstring")  DiffuseElement::polarizationHandler "const PolarizationHandler& DiffuseElement::polarizationHandler() const

Returns assigned PolarizationHandler. 
";

%feature("docstring")  DiffuseElement::wavelength "double DiffuseElement::wavelength() const
";

%feature("docstring")  DiffuseElement::getAlphaI "double DiffuseElement::getAlphaI() const
";

%feature("docstring")  DiffuseElement::getPhiI "double DiffuseElement::getPhiI() const
";

%feature("docstring")  DiffuseElement::getAlphaMean "double DiffuseElement::getAlphaMean() const
";

%feature("docstring")  DiffuseElement::getPhiMean "double DiffuseElement::getPhiMean() const
";

%feature("docstring")  DiffuseElement::setIntensity "void DiffuseElement::setIntensity(double intensity)
";

%feature("docstring")  DiffuseElement::addIntensity "void DiffuseElement::addIntensity(double intensity)
";

%feature("docstring")  DiffuseElement::intensity "double DiffuseElement::intensity() const
";

%feature("docstring")  DiffuseElement::getKi "kvector_t DiffuseElement::getKi() const
";

%feature("docstring")  DiffuseElement::getMeanKf "kvector_t DiffuseElement::getMeanKf() const
";

%feature("docstring")  DiffuseElement::meanQ "kvector_t DiffuseElement::meanQ() const
";

%feature("docstring")  DiffuseElement::getQ "kvector_t DiffuseElement::getQ(double x, double y) const

Returns scattering vector Q, with Kf determined from in-pixel coordinates x,y. In-pixel coordinates take values from 0 to 1. 
";

%feature("docstring")  DiffuseElement::integrationFactor "double DiffuseElement::integrationFactor(double x, double y) const
";

%feature("docstring")  DiffuseElement::solidAngle "double DiffuseElement::solidAngle() const
";

%feature("docstring")  DiffuseElement::getAlpha "double DiffuseElement::getAlpha(double x, double y) const
";

%feature("docstring")  DiffuseElement::getPhi "double DiffuseElement::getPhi(double x, double y) const
";

%feature("docstring")  DiffuseElement::wavevectorInfo "WavevectorInfo DiffuseElement::wavevectorInfo() const
";

%feature("docstring")  DiffuseElement::isSpecular "bool DiffuseElement::isSpecular() const

Tells if simulation element corresponds to a specular peak. 
";


// File: classFluxes.xml
%feature("docstring") Fluxes "";


// File: classIComputeFF.xml
%feature("docstring") IComputeFF "

Abstract base class for form factor evaluations.

Wraps an IFormFactor, and provides functions evaluate or evaluatePol.

C++ includes: IComputeFF.h
";

%feature("docstring")  IComputeFF::~IComputeFF "IComputeFF::~IComputeFF()
";

%feature("docstring")  IComputeFF::clone "virtual IComputeFF* IComputeFF::clone() const =0
";

%feature("docstring")  IComputeFF::iLayer "size_t IComputeFF::iLayer() const
";

%feature("docstring")  IComputeFF::volume "double IComputeFF::volume() const
";

%feature("docstring")  IComputeFF::radialExtension "double IComputeFF::radialExtension() const
";

%feature("docstring")  IComputeFF::bottomZ "double IComputeFF::bottomZ(const IRotation &rotation) const
";

%feature("docstring")  IComputeFF::topZ "double IComputeFF::topZ(const IRotation &rotation) const
";


// File: classIComputePol.xml
%feature("docstring") IComputePol "

Provides polarized form factor evaluation for given IFormFactor. Inherited by  ComputeBAPol and  ComputeDWBAPol.

C++ includes: IComputePol.h
";

%feature("docstring")  IComputePol::coherentPolFF "Eigen::Matrix2cd IComputePol::coherentPolFF(const DiffuseElement &sim_element) const
";

%feature("docstring")  IComputePol::computePolFF "virtual Eigen::Matrix2cd IComputePol::computePolFF(const WavevectorInfo &wavevectors, const std::unique_ptr< const IFlux > &inFlux, const std::unique_ptr< const IFlux > &outFlux) const =0

Returns scattering amplitude for matrix interactions. 
";


// File: classIComputeScalar.xml
%feature("docstring") IComputeScalar "

Provides scalar form factor evaluation for given IFormFactor. Inherited by  ComputeBA and  ComputeDWBA.

C++ includes: IComputeScalar.h
";

%feature("docstring")  IComputeScalar::computeFF "virtual complex_t IComputeScalar::computeFF(const WavevectorInfo &wavevectors, const std::unique_ptr< const IFlux > &inFlux, const std::unique_ptr< const IFlux > &outFlux) const =0
";

%feature("docstring")  IComputeScalar::coherentFF "complex_t IComputeScalar::coherentFF(const DiffuseElement &sim_element) const
";


// File: classIFlux.xml
%feature("docstring") IFlux "

Interface to access reflection/transmission coefficients. Realized by  ScalarFlux and  MatrixFlux.

C++ includes: IFlux.h
";

%feature("docstring")  IFlux::~IFlux "virtual IFlux::~IFlux()=default
";

%feature("docstring")  IFlux::clone "virtual IFlux* IFlux::clone() const =0
";

%feature("docstring")  IFlux::T1plus "virtual Eigen::Vector2cd IFlux::T1plus() const =0

The following functions return the transmitted and reflected amplitudes for different incoming beam polarizations and eigenmodes 
";

%feature("docstring")  IFlux::R1plus "virtual Eigen::Vector2cd IFlux::R1plus() const =0
";

%feature("docstring")  IFlux::T2plus "virtual Eigen::Vector2cd IFlux::T2plus() const =0
";

%feature("docstring")  IFlux::R2plus "virtual Eigen::Vector2cd IFlux::R2plus() const =0
";

%feature("docstring")  IFlux::T1min "virtual Eigen::Vector2cd IFlux::T1min() const =0
";

%feature("docstring")  IFlux::R1min "virtual Eigen::Vector2cd IFlux::R1min() const =0
";

%feature("docstring")  IFlux::T2min "virtual Eigen::Vector2cd IFlux::T2min() const =0
";

%feature("docstring")  IFlux::R2min "virtual Eigen::Vector2cd IFlux::R2min() const =0
";

%feature("docstring")  IFlux::getKz "virtual Eigen::Vector2cd IFlux::getKz() const =0

Returns z-part of the two wavevector eigenmodes. 
";

%feature("docstring")  IFlux::getScalarT "virtual complex_t IFlux::getScalarT() const
";

%feature("docstring")  IFlux::getScalarR "virtual complex_t IFlux::getScalarR() const
";

%feature("docstring")  IFlux::getScalarKz "virtual complex_t IFlux::getScalarKz() const
";


// File: classIInterparticleStrategy.xml
%feature("docstring") IInterparticleStrategy "

Abstract base class of  DecouplingApproximationStrategy,  SSCAStrategy. Provides function 'evaluate' that computes the total scattering intensity from a decorated layer.

Instantiation of child classes takes place in LayoutStrategyBuilder::createStrategy, which is called from ParticleLayoutContribution::eval.

C++ includes: IInterparticleStrategy.h
";

%feature("docstring")  IInterparticleStrategy::IInterparticleStrategy "IInterparticleStrategy::IInterparticleStrategy(const std::vector< CoherentFFSum > &weighted_formfactors, const SimulationOptions &sim_params, bool polarized)
";

%feature("docstring")  IInterparticleStrategy::~IInterparticleStrategy "IInterparticleStrategy::~IInterparticleStrategy()
";

%feature("docstring")  IInterparticleStrategy::evaluate "double IInterparticleStrategy::evaluate(const DiffuseElement &sim_element) const

Calculates the intensity for scalar particles/interactions. 
";


// File: classIntegratorMCMiser.xml
%feature("docstring") IntegratorMCMiser "";


// File: classISpecularStrategy.xml
%feature("docstring") ISpecularStrategy "

Interface for the Fresnel computations, both in the scalar and magnetic case

Inherited by  SpecularScalarStrategy,  SpecularMagneticStrategy.

C++ includes: ISpecularStrategy.h
";

%feature("docstring")  ISpecularStrategy::ISpecularStrategy "ISpecularStrategy::ISpecularStrategy()=default
";

%feature("docstring")  ISpecularStrategy::~ISpecularStrategy "virtual ISpecularStrategy::~ISpecularStrategy()=default
";

%feature("docstring")  ISpecularStrategy::ISpecularStrategy "ISpecularStrategy::ISpecularStrategy(const ISpecularStrategy &other)=delete
";

%feature("docstring")  ISpecularStrategy::Execute "virtual Fluxes ISpecularStrategy::Execute(const SliceStack &slices, const kvector_t &k) const =0
";

%feature("docstring")  ISpecularStrategy::computeTopLayerR "virtual std::variant<complex_t, Eigen::Matrix2cd> ISpecularStrategy::computeTopLayerR(const SliceStack &slices, const std::vector< complex_t > &kz) const =0
";


// File: classLayerFillLimits.xml
%feature("docstring") LayerFillLimits "

Helper class for the graded layer approximation. Generates limits for each layer, indicating the region of the layer (along z) that contains particle(s)

The constructor takes the bottom layer z-coordinates as parameter. This means that for N layers, only N-1 coordinates need to be passed (the last layer is assumed to be semi-infinite). 
";

%feature("docstring")  LayerFillLimits::LayerFillLimits "LayerFillLimits::LayerFillLimits(std::vector< double > layers_bottomz)
";

%feature("docstring")  LayerFillLimits::update "void LayerFillLimits::update(ZLimits particle_limits, double offset=0.0)

Particle limits are given in global coordinates. 
";

%feature("docstring")  LayerFillLimits::layerZLimits "std::vector< ZLimits > LayerFillLimits::layerZLimits() const

Returns the filled region limits for each layer (in local layer coordinates) 
";


// File: classMatrixFlux.xml
%feature("docstring") MatrixFlux "

Specular reflection and transmission coefficients in a layer in case of magnetic interactions between the scattered particle and the layer.

C++ includes: MatrixFlux.h
";

%feature("docstring")  MatrixFlux::MatrixFlux "MatrixFlux::MatrixFlux(double kz_sign, Eigen::Vector2cd eigenvalues, kvector_t b, double magnetic_SLD)
";

%feature("docstring")  MatrixFlux::clone "MatrixFlux * MatrixFlux::clone() const override
";

%feature("docstring")  MatrixFlux::T1plus "Eigen::Vector2cd MatrixFlux::T1plus() const override

The following functions return the transmitted and reflected amplitudes for different incoming beam polarizations and eigenmodes 
";

%feature("docstring")  MatrixFlux::R1plus "Eigen::Vector2cd MatrixFlux::R1plus() const override
";

%feature("docstring")  MatrixFlux::T2plus "Eigen::Vector2cd MatrixFlux::T2plus() const override
";

%feature("docstring")  MatrixFlux::R2plus "Eigen::Vector2cd MatrixFlux::R2plus() const override
";

%feature("docstring")  MatrixFlux::T1min "Eigen::Vector2cd MatrixFlux::T1min() const override
";

%feature("docstring")  MatrixFlux::R1min "Eigen::Vector2cd MatrixFlux::R1min() const override
";

%feature("docstring")  MatrixFlux::T2min "Eigen::Vector2cd MatrixFlux::T2min() const override
";

%feature("docstring")  MatrixFlux::R2min "Eigen::Vector2cd MatrixFlux::R2min() const override
";

%feature("docstring")  MatrixFlux::getKz "Eigen::Vector2cd MatrixFlux::getKz() const override

Returns z-part of the two wavevector eigenmodes. 
";

%feature("docstring")  MatrixFlux::magneticSLD "double MatrixFlux::magneticSLD() const
";

%feature("docstring")  MatrixFlux::computeP "Eigen::Matrix2cd MatrixFlux::computeP() const
";

%feature("docstring")  MatrixFlux::computeInverseP "Eigen::Matrix2cd MatrixFlux::computeInverseP() const
";

%feature("docstring")  MatrixFlux::computeDeltaMatrix "Eigen::Matrix2cd MatrixFlux::computeDeltaMatrix(double thickness)
";

%feature("docstring")  MatrixFlux::getReflectionMatrix "Eigen::Matrix2cd MatrixFlux::getReflectionMatrix() const
";


// File: classProcessedLayout.xml
%feature("docstring") ProcessedLayout "

Data structure that contains preprocessed data for a single layout.

If particles in the layout crossed the limits of the layer slices, these particles will be sliced themselves.

C++ includes: ProcessedLayout.h
";

%feature("docstring")  ProcessedLayout::ProcessedLayout "ProcessedLayout::ProcessedLayout(const ParticleLayout &layout, const SliceStack &slices, double z_ref, bool polarized)
";

%feature("docstring")  ProcessedLayout::ProcessedLayout "ProcessedLayout::ProcessedLayout(ProcessedLayout &&other)
";

%feature("docstring")  ProcessedLayout::~ProcessedLayout "ProcessedLayout::~ProcessedLayout()
";

%feature("docstring")  ProcessedLayout::numberOfSlices "size_t ProcessedLayout::numberOfSlices() const
";

%feature("docstring")  ProcessedLayout::surfaceDensity "double ProcessedLayout::surfaceDensity() const
";

%feature("docstring")  ProcessedLayout::formFactorList "const std::vector< CoherentFFSum > & ProcessedLayout::formFactorList() const
";

%feature("docstring")  ProcessedLayout::interferenceFunction "const IInterferenceFunction * ProcessedLayout::interferenceFunction() const
";

%feature("docstring")  ProcessedLayout::regionMap "const std::map< size_t, Admixtures > & ProcessedLayout::regionMap() const
";


// File: classProcessedSample.xml
%feature("docstring") ProcessedSample "

Data structure that contains all the necessary data for scattering calculations.

If the usage of average materials is requested, layers and particles are sliced into multiple slices and the average material is calculated for each slice.

C++ includes: ProcessedSample.h
";

%feature("docstring")  ProcessedSample::ProcessedSample "ProcessedSample::ProcessedSample(const ProcessedSample &)=delete
";

%feature("docstring")  ProcessedSample::ProcessedSample "ProcessedSample::ProcessedSample(ProcessedSample &&)
";

%feature("docstring")  ProcessedSample::~ProcessedSample "ProcessedSample::~ProcessedSample()
";

%feature("docstring")  ProcessedSample::numberOfSlices "size_t ProcessedSample::numberOfSlices() const
";

%feature("docstring")  ProcessedSample::averageSlices "const SliceStack & ProcessedSample::averageSlices() const
";

%feature("docstring")  ProcessedSample::avgeSlice "const Slice & ProcessedSample::avgeSlice(size_t i) const
";

%feature("docstring")  ProcessedSample::layouts "const std::vector< ProcessedLayout > & ProcessedSample::layouts() const
";

%feature("docstring")  ProcessedSample::getSpecularStrategy "const ISpecularStrategy * ProcessedSample::getSpecularStrategy() const
";

%feature("docstring")  ProcessedSample::sliceTopZ "double ProcessedSample::sliceTopZ(size_t i) const
";

%feature("docstring")  ProcessedSample::sliceBottomZ "double ProcessedSample::sliceBottomZ(size_t i) const
";

%feature("docstring")  ProcessedSample::containsMagneticMaterial "bool ProcessedSample::containsMagneticMaterial() const
";

%feature("docstring")  ProcessedSample::polarizing "bool ProcessedSample::polarizing() const

Contains magnetic material, or nonzero magnetic field. 
";

%feature("docstring")  ProcessedSample::hasRoughness "bool ProcessedSample::hasRoughness() const
";

%feature("docstring")  ProcessedSample::sample "const MultiLayer& ProcessedSample::sample() const
";

%feature("docstring")  ProcessedSample::fluxesIn "Fluxes ProcessedSample::fluxesIn(const kvector_t &k) const
";

%feature("docstring")  ProcessedSample::fluxesOut "Fluxes ProcessedSample::fluxesOut(const kvector_t &k) const
";

%feature("docstring")  ProcessedSample::crossCorrSpectralFun "double ProcessedSample::crossCorrSpectralFun(const kvector_t kvec, size_t j, size_t k) const

Fourier transform of the correlation function of roughnesses between the interfaces. 
";


// File: classProfileHelper.xml
%feature("docstring") ProfileHelper "

Object that can generate the material profile of a sample as a function of depth.

The generated profile contains the complex SLD for SLD materials and the parameters delta and beta for refractive index materials

C++ includes: ProfileHelper.h
";

%feature("docstring")  ProfileHelper::ProfileHelper "ProfileHelper::ProfileHelper(const ProcessedSample &sample)
";

%feature("docstring")  ProfileHelper::~ProfileHelper "ProfileHelper::~ProfileHelper()
";

%feature("docstring")  ProfileHelper::calculateProfile "std::vector< complex_t > ProfileHelper::calculateProfile(const std::vector< double > &z_values) const
";

%feature("docstring")  ProfileHelper::defaultLimits "std::pair< double, double > ProfileHelper::defaultLimits() const
";


// File: classScalarFlux.xml
%feature("docstring") ScalarFlux "

Specular reflection and transmission coefficients in a layer in case of scalar interactions between the layers and the scattered particle.

C++ includes: ScalarFlux.h
";

%feature("docstring")  ScalarFlux::ScalarFlux "ScalarFlux::ScalarFlux(complex_t kz, Eigen::Vector2cd TR)
";

%feature("docstring")  ScalarFlux::clone "ScalarFlux * ScalarFlux::clone() const
";

%feature("docstring")  ScalarFlux::T1plus "Eigen::Vector2cd ScalarFlux::T1plus() const

The following functions return the transmitted and reflected amplitudes for different incoming beam polarizations and eigenmodes 
";

%feature("docstring")  ScalarFlux::R1plus "Eigen::Vector2cd ScalarFlux::R1plus() const
";

%feature("docstring")  ScalarFlux::T2plus "Eigen::Vector2cd ScalarFlux::T2plus() const
";

%feature("docstring")  ScalarFlux::R2plus "Eigen::Vector2cd ScalarFlux::R2plus() const
";

%feature("docstring")  ScalarFlux::T1min "Eigen::Vector2cd ScalarFlux::T1min() const
";

%feature("docstring")  ScalarFlux::R1min "Eigen::Vector2cd ScalarFlux::R1min() const
";

%feature("docstring")  ScalarFlux::T2min "Eigen::Vector2cd ScalarFlux::T2min() const
";

%feature("docstring")  ScalarFlux::R2min "Eigen::Vector2cd ScalarFlux::R2min() const
";

%feature("docstring")  ScalarFlux::getKz "Eigen::Vector2cd ScalarFlux::getKz() const

Returns z-part of the two wavevector eigenmodes. 
";

%feature("docstring")  ScalarFlux::getScalarT "complex_t ScalarFlux::getScalarT() const
";

%feature("docstring")  ScalarFlux::getScalarR "complex_t ScalarFlux::getScalarR() const
";

%feature("docstring")  ScalarFlux::getScalarKz "virtual complex_t ScalarFlux::getScalarKz() const
";


// File: classSimulationOptions.xml
%feature("docstring") SimulationOptions "

Collect the different options for simulation.

SimulationOptions

C++ includes: SimulationOptions.h
";

%feature("docstring")  SimulationOptions::SimulationOptions "SimulationOptions::SimulationOptions()
";

%feature("docstring")  SimulationOptions::isIntegrate "bool SimulationOptions::isIntegrate() const
";

%feature("docstring")  SimulationOptions::getMcPoints "size_t SimulationOptions::getMcPoints() const
";

%feature("docstring")  SimulationOptions::setMonteCarloIntegration "void SimulationOptions::setMonteCarloIntegration(bool flag=true, size_t mc_points=50)

Enables/disables MonetCarlo integration.

Parameters:
-----------

flag: 
If true, MonteCarlo integration will be used, otherwise analytical calculations

mc_points: 
Number of points for MonteCarlo integrator 
";

%feature("docstring")  SimulationOptions::setNumberOfThreads "void SimulationOptions::setNumberOfThreads(int nthreads)

Sets number of threads to use during the simulation (0 - take the default value from the hardware) 
";

%feature("docstring")  SimulationOptions::getNumberOfThreads "unsigned SimulationOptions::getNumberOfThreads() const
";

%feature("docstring")  SimulationOptions::setNumberOfBatches "void SimulationOptions::setNumberOfBatches(int nbatches)

Sets number of batches to split. 
";

%feature("docstring")  SimulationOptions::getNumberOfBatches "unsigned SimulationOptions::getNumberOfBatches() const
";

%feature("docstring")  SimulationOptions::getCurrentBatch "unsigned SimulationOptions::getCurrentBatch() const
";

%feature("docstring")  SimulationOptions::setThreadInfo "void SimulationOptions::setThreadInfo(const ThreadInfo &thread_info)

Sets the batch and thread information to be used. 
";

%feature("docstring")  SimulationOptions::getHardwareConcurrency "unsigned SimulationOptions::getHardwareConcurrency() const
";

%feature("docstring")  SimulationOptions::setIncludeSpecular "void SimulationOptions::setIncludeSpecular(bool include_specular)
";

%feature("docstring")  SimulationOptions::includeSpecular "bool SimulationOptions::includeSpecular() const
";

%feature("docstring")  SimulationOptions::setUseAvgMaterials "void SimulationOptions::setUseAvgMaterials(bool use_avg_materials)
";

%feature("docstring")  SimulationOptions::useAvgMaterials "bool SimulationOptions::useAvgMaterials() const
";


// File: classSlice.xml
%feature("docstring") Slice "

Data structure containing the data of a single slice, for calculating the Fresnel coefficients.

C++ includes: Slice.h
";

%feature("docstring")  Slice::Slice "Slice::Slice(const ZLimits &zRange, const Material &material, const kvector_t &B_field, const LayerRoughness *const roughness)
";

%feature("docstring")  Slice::Slice "Slice::Slice(const Slice &other)
";

%feature("docstring")  Slice::Slice "Slice::Slice(Slice &&other)
";

%feature("docstring")  Slice::~Slice "Slice::~Slice()
";

%feature("docstring")  Slice::setMaterial "void Slice::setMaterial(const Material &material)
";

%feature("docstring")  Slice::material "const Material & Slice::material() const
";

%feature("docstring")  Slice::zBottom "double Slice::zBottom() const
";

%feature("docstring")  Slice::zTop "double Slice::zTop() const
";

%feature("docstring")  Slice::zTopOr0 "double Slice::zTopOr0() const
";

%feature("docstring")  Slice::thicknessOr0 "double Slice::thicknessOr0() const
";

%feature("docstring")  Slice::topRoughness "const LayerRoughness * Slice::topRoughness() const
";

%feature("docstring")  Slice::scalarReducedPotential "complex_t Slice::scalarReducedPotential(kvector_t k, double n_ref) const

Return the potential term that is used in the one-dimensional Fresnel calculations. 
";

%feature("docstring")  Slice::polarizedReducedPotential "Eigen::Matrix2cd Slice::polarizedReducedPotential(kvector_t k, double n_ref) const

Return the potential term that is used in the one-dimensional Fresnel calculations in the presence of magnetization 
";

%feature("docstring")  Slice::initBField "void Slice::initBField(kvector_t h_field, double h_z)

Initializes the magnetic B field from a given ambient field strength H. 
";

%feature("docstring")  Slice::bField "kvector_t Slice::bField() const
";

%feature("docstring")  Slice::invertBField "void Slice::invertBField()
";


// File: classSliceStack.xml
%feature("docstring") SliceStack "

A stack of  Slices.

C++ includes: SliceStack.h
";

%feature("docstring")  SliceStack::addTopSlice "void SliceStack::addTopSlice(double zbottom, const Material &material)
";

%feature("docstring")  SliceStack::addSlice "void SliceStack::addSlice(double thickness, const Material &material, const LayerRoughness *roughness=nullptr)
";

%feature("docstring")  SliceStack::addNSlices "void SliceStack::addNSlices(size_t n, double thickness, const Material &material, const LayerRoughness *const roughness=nullptr)

Adds n times the same slice to the stack. 
";

%feature("docstring")  SliceStack::setBField "SliceStack SliceStack::setBField(const kvector_t &externalField)
";

%feature("docstring")  SliceStack::containsMagneticMaterial "bool SliceStack::containsMagneticMaterial() const
";

%feature("docstring")  SliceStack::bottomRoughness "const LayerRoughness * SliceStack::bottomRoughness(size_t i_slice) const
";


// File: classSpecularMagneticNCStrategy.xml
%feature("docstring") SpecularMagneticNCStrategy "

Implements the magnetic Fresnel computation with Nevot-Croce roughness

Implements the transfer matrix formalism for the calculation of wave amplitudes of the coherent wave solution in a multilayer with magnetization. For a description, see internal document \"Polarized Implementation of the Transfer Matrix Method\"

C++ includes: SpecularMagneticNCStrategy.h
";


// File: classSpecularMagneticStrategy.xml
%feature("docstring") SpecularMagneticStrategy "

Implements the magnetic Fresnel computation with Nevot-Croce roughness

Implements the transfer matrix formalism for the calculation of wave amplitudes of the coherent wave solution in a multilayer with magnetization. For a description, see internal document \"Polarized Implementation of the Transfer Matrix Method\"

C++ includes: SpecularMagneticStrategy.h
";

%feature("docstring")  SpecularMagneticStrategy::Execute "Fluxes SpecularMagneticStrategy::Execute(const SliceStack &slices, const kvector_t &k) const override

Computes refraction angle reflection/transmission coefficients for given sliced multilayer and wavevector k 
";

%feature("docstring")  SpecularMagneticStrategy::Execute "Fluxes SpecularMagneticStrategy::Execute(const SliceStack &slices, const std::vector< complex_t > &kz) const override

Computes refraction angle reflection/transmission coefficients for given sliced multilayer and a set of kz projections corresponding to each slice 
";

%feature("docstring")  SpecularMagneticStrategy::computeTopLayerR "std::variant< complex_t, Eigen::Matrix2cd > SpecularMagneticStrategy::computeTopLayerR(const SliceStack &slices, const std::vector< complex_t > &kzs) const override

Computes the Fresnel R coefficient for the top layer only Introduced in order to speed up pure reflectivity computations 
";


// File: classSpecularMagneticTanhStrategy.xml
%feature("docstring") SpecularMagneticTanhStrategy "

Implements the magnetic Fresnel computation with the analytical Tanh roughness

Implements the transfer matrix formalism for the calculation of wave amplitudes of the coherent wave solution in a multilayer with magnetization. For a description, see internal document \"Polarized Implementation of the Transfer Matrix Method\"

C++ includes: SpecularMagneticTanhStrategy.h
";


// File: classSpecularScalarNCStrategy.xml
%feature("docstring") SpecularScalarNCStrategy "

Implements Nevot-Croce roughness for a scaler computation.

Implements the transition function that includes Nevot-Croce roughness in the computation of the coefficients for coherent wave propagation in a multilayer by applying modified Fresnel coefficients.

C++ includes: SpecularScalarNCStrategy.h
";


// File: classSpecularScalarStrategy.xml
%feature("docstring") SpecularScalarStrategy "

Implements the scalar Fresnel computation

Implements method 'execute' to compute refraction angles and transmission/reflection coefficients for coherent wave propagation in a multilayer.

Inherited by  SpecularScalarNCStrategy,  SpecularScalarTanhStrategy

C++ includes: SpecularScalarStrategy.h
";

%feature("docstring")  SpecularScalarStrategy::Execute "Fluxes SpecularScalarStrategy::Execute(const SliceStack &slices, const kvector_t &k) const override

Computes refraction angles and transmission/reflection coefficients for given coherent wave propagation in a multilayer. 
";


// File: classSpecularScalarTanhStrategy.xml
%feature("docstring") SpecularScalarTanhStrategy "

Implements an tanh transition function to model roughness in a scaler computation.

Implements the transition function that includes the analytical roughness model of an tanh interface transition in the computation of the coefficients for coherent wave propagation in a multilayer by applying modified Fresnel coefficients.

C++ includes: SpecularScalarTanhStrategy.h
";


// File: classSSCAStrategy.xml
%feature("docstring") SSCAStrategy "

Strategy class to compute the total scattering from a particle layout in the size-spacing correlation approximation.

C++ includes: SSCAStrategy.h
";

%feature("docstring")  SSCAStrategy::SSCAStrategy "SSCAStrategy::SSCAStrategy(const std::vector< CoherentFFSum > &weighted_formfactors, const InterferenceFunctionRadialParaCrystal *iff, SimulationOptions sim_params, bool polarized, double kappa)
";


// File: namespace_0d10.xml


// File: namespace_0d19.xml


// File: namespace_0d27.xml


// File: namespace_0d31.xml


// File: namespace_0d33.xml


// File: namespace_0d35.xml


// File: namespace_0d37.xml


// File: namespace_0d39.xml


// File: namespace_0d46.xml


// File: namespace_0d48.xml


// File: namespaceSampleUtils.xml


// File: namespaceSampleUtils_1_1KzComputation.xml
%feature("docstring")  SampleUtils::KzComputation::computeReducedKz "std::vector< complex_t > SampleUtils::KzComputation::computeReducedKz(const SliceStack &slices, kvector_t k)
";

%feature("docstring")  SampleUtils::KzComputation::computeKzFromSLDs "std::vector< complex_t > SampleUtils::KzComputation::computeKzFromSLDs(const SliceStack &slices, double kz)
";

%feature("docstring")  SampleUtils::KzComputation::computeKzFromRefIndices "std::vector< complex_t > SampleUtils::KzComputation::computeKzFromRefIndices(const SliceStack &slices, kvector_t k)
";


// File: namespaceSampleUtils_1_1Preprocessor.xml
%feature("docstring")  SampleUtils::Preprocessor::particleRegions "std::vector< ZLimits > SampleUtils::Preprocessor::particleRegions(const MultiLayer &multilayer, bool use_slicing)

Calculate z-admixtures occupied by particles. 
";


// File: namespaceSampleUtils_1_1SpecularStrategyBuilder.xml
%feature("docstring")  SampleUtils::SpecularStrategyBuilder::buildScalar "std::unique_ptr< SpecularScalarStrategy > SampleUtils::SpecularStrategyBuilder::buildScalar(const RoughnessModel &rm)
";

%feature("docstring")  SampleUtils::SpecularStrategyBuilder::buildMagnetic "std::unique_ptr< SpecularMagneticStrategy > SampleUtils::SpecularStrategyBuilder::buildMagnetic(const RoughnessModel &rm)
";


// File: namespacestd.xml


// File: namespaceswigAPI.xml
%feature("docstring")  swigAPI::generateZValues "std::vector< double > swigAPI::generateZValues(int n_points, double z_min, double z_max)
";

%feature("docstring")  swigAPI::materialProfileSLD "std::vector< complex_t > swigAPI::materialProfileSLD(const MultiLayer &multilayer, int n_points, double z_min, double z_max)

Calculate average material profile for given multilayer. 
";

%feature("docstring")  swigAPI::defaultMaterialProfileLimits "std::pair< double, double > swigAPI::defaultMaterialProfileLimits(const MultiLayer &multilayer)

Get default z limits for generating a material profile. 
";


// File: FFSum_8cpp.xml


// File: FFSum_8h.xml


// File: DiffuseElement_8cpp.xml


// File: DiffuseElement_8h.xml


// File: ComputeBA_8cpp.xml


// File: ComputeBA_8h.xml


// File: ComputeBAPol_8cpp.xml


// File: ComputeBAPol_8h.xml


// File: ComputeDWBA_8cpp.xml


// File: ComputeDWBA_8h.xml


// File: ComputeDWBAPol_8cpp.xml


// File: ComputeDWBAPol_8h.xml


// File: IComputeFF_8cpp.xml


// File: IComputeFF_8h.xml


// File: IComputePol_8cpp.xml


// File: IComputePol_8h.xml


// File: IComputeScalar_8cpp.xml


// File: IComputeScalar_8h.xml


// File: IFlux_8h.xml


// File: MatrixFlux_8cpp.xml


// File: MatrixFlux_8h.xml


// File: ScalarFlux_8cpp.xml


// File: ScalarFlux_8h.xml


// File: DecouplingApproximationStrategy_8cpp.xml


// File: DecouplingApproximationStrategy_8h.xml


// File: IInterparticleStrategy_8cpp.xml


// File: IInterparticleStrategy_8h.xml


// File: SSCAStrategy_8cpp.xml


// File: SSCAStrategy_8h.xml


// File: SimulationOptions_8cpp.xml


// File: SimulationOptions_8h.xml


// File: ParticleRegions_8cpp.xml


// File: ParticleRegions_8h.xml


// File: ProcessedLayout_8cpp.xml


// File: ProcessedLayout_8h.xml


// File: ProcessedSample_8cpp.xml


// File: ProcessedSample_8h.xml


// File: ProfileHelper_8cpp.xml


// File: ProfileHelper_8h.xml


// File: KzComputation_8cpp.xml


// File: KzComputation_8h.xml


// File: Slice_8cpp.xml


// File: Slice_8h.xml


// File: SliceStack_8cpp.xml


// File: SliceStack_8h.xml


// File: ISpecularStrategy_8h.xml


// File: SpecularMagneticNCStrategy_8cpp.xml


// File: SpecularMagneticNCStrategy_8h.xml


// File: SpecularMagneticStrategy_8cpp.xml


// File: SpecularMagneticStrategy_8h.xml


// File: SpecularMagneticTanhStrategy_8cpp.xml


// File: SpecularMagneticTanhStrategy_8h.xml


// File: SpecularScalarNCStrategy_8cpp.xml


// File: SpecularScalarNCStrategy_8h.xml


// File: SpecularScalarStrategy_8cpp.xml


// File: SpecularScalarStrategy_8h.xml


// File: SpecularScalarTanhStrategy_8cpp.xml


// File: SpecularScalarTanhStrategy_8h.xml


// File: SpecularStrategyBuilder_8cpp.xml


// File: SpecularStrategyBuilder_8h.xml


// File: MultiLayerFuncs_8cpp.xml


// File: MultiLayerFuncs_8h.xml


// File: dir_05914d190eb55651e85671c4f064dae1.xml


// File: dir_28bc1277e419364b011e46aeb2e8e251.xml


// File: dir_5e69988b243d40135cf1f8fc1086c5f7.xml


// File: dir_4ab1bbd9e8de6a7ddc078bbf4801b604.xml


// File: dir_f2e99fd688553c1021427f9f47ee68cc.xml


// File: dir_fc04159ec4b49a4525d9d1e735a03048.xml


// File: dir_8b8e406e0c078f14186b4022c818284f.xml


// File: dir_dd8f7bdc5adb03cd4741fd30e320356d.xml


// File: dir_5a6fad4f9f1572339acc49c35f6f6afa.xml


// File: dir_1581d6c09e9e4d82c1ed930bcfd40548.xml


// File: dir_3d5d340a448876c17068ec92885910e5.xml

